@@ -1028,6 +1028,12 @@ generate_local_classic (classic_reader_t *reader, int min_distance, int metric)
 
 	    match = metapixel_nearest_to(&coeffs, metric, x, y, neighborhood, neighborhood_size, 0, 0);
 
+	    if (match.pixel == 0)
+	    {
+		fprintf(stderr, "Error: cannot find a matching image - try using a shorter distance.\n");
+		exit(1);
+	    }
+
 	    mosaic->matches[y * metawidth + x] = match;
 
 	    printf(".");
@@ -1917,6 +1923,8 @@ main (int argc, char *argv[])
 
     small_width = default_small_width;
     small_height = default_small_height;
+    prepare_width = default_prepare_width;
+    prepare_height = default_prepare_height;
     memcpy(weight_factors, default_weight_factors, sizeof(weight_factors));
     metric = default_metric;
     search = default_search;
